EncryptionType enum

Wifi encryption type constants.

Inheritance
Available extensions

Values

unknown → const EncryptionType

Unknown encryption type.

const EncryptionType(0)
open → const EncryptionType

Not encrypted.

const EncryptionType(1)
wpa → const EncryptionType

WPA level encryption.

const EncryptionType(2)
wep → const EncryptionType

WEP level encryption.

const EncryptionType(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue int
The raw value for the encryption type.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

none → const EncryptionType
values → const List<EncryptionType>
A constant List of the values in this enum, in order of their declaration.