MobileScannerErrorCode enum

This enum defines the different error codes for the mobile scanner.

Inheritance
Available extensions

Values

controllerAlreadyInitialized → const MobileScannerErrorCode

The controller was already started.

The controller should be stopped using MobileScannerController.stop, before restarting it.

controllerDisposed → const MobileScannerErrorCode

The controller was used after being disposed.

controllerUninitialized → const MobileScannerErrorCode

The controller was used while it was not yet initialized using MobileScannerController.start.

genericError → const MobileScannerErrorCode

A generic error occurred.

This error code is used for all errors that do not have a specific error code.

permissionDenied → const MobileScannerErrorCode

The permission to use the camera was denied.

unsupported → const MobileScannerErrorCode

Scanning is unsupported on the current device.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
message String
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MobileScannerErrorCode>
A constant List of the values in this enum, in order of their declaration.